# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import TypedDict

__all__ = ["ComputerRightClickParams"]


class ComputerRightClickParams(TypedDict, total=False):
    tab_id: str

    x: float

    y: float
